# Basic Tutorials

From Zero to Hero in 5 tutorials.

In 5 lessons, you learn everything that you need to know to create a Stroop experiment with SweetBean. At the end you
will know how different variable types in SweetBean work and how to use them to create a task switching experiment with
Stroop stimuli.
